A library for parsing TSPLIB file formats.
The original documentation for TSPLIB can be found in the website of Ruprecht-Karls-Universität Heidelberg.
Modules
Structs
- Represents a node coordinate.
- Represents a parsed TSP dataset.
- Responsible for constructing an instance of
Tsp.
Enums
- Specifies how node coordinates are stored in a file.
- Specifies how node coordinates for display purpose are stored in a file.
- Specifies how list of edges are stored in a file.
- An enum for errors that might occur during parsing.
- Enum for TSP’s variants.
- Specifies how edge weights are stored in a file.
- An enum for distance functions defined in the
TSPLIBformat.